@@ -36,7 +36,7 @@ static void printCommandFormatHelpJson(void)
             yyjson_mut_val* obj = yyjson_mut_obj(doc);
             if (yyjson_mut_obj_add(root, yyjson_mut_strbuf(doc, &type), obj))
             {
-                FF_STRBUF_AUTO_DESTROY content = ffStrbufCreateF("Output format of the module `%s`. See `-h format` for formatting syntax\n", baseInfo->name);
+                FF_STRBUF_AUTO_DESTROY content = ffStrbufCreateF("Output format of the module `%s`. See Wiki for formatting syntax\n", baseInfo->name);
                 for (unsigned i = 0; i < baseInfo->formatArgs.count; i++)
                 {
                     const FFModuleFormatArg* arg = &baseInfo->formatArgs.args[i];
@@ -180,7 +180,11 @@ static void printFullHelp()
     }
     yyjson_doc_free(doc);
 
-    puts("\n" FASTFETCH_DATATEXT_HELP_FOOTER);
+    puts("\n\
+Parsing is not case sensitive. E.g. `--print-logos` is equal to `--Print-Logos`\n\
+If a value starts with a ?, it is optional. An optional boolean value defaults to true if not specified.\n\
+More detailed help messages for each options can be printed with `-h <option_without_dash_prefix>`\n\
+All options can be made permanent with command `fastfetch <options> --gen-config`");
 }
 
 static bool printSpecificCommandHelp(const char* command)
@@ -298,10 +302,6 @@ static void printCommandHelp(const char* command)
 {
     if(command == NULL)
         printFullHelp();
-    else if(ffStrEqualsIgnCase(command, "color"))
-        puts(FASTFETCH_DATATEXT_HELP_COLOR);
-    else if(ffStrEqualsIgnCase(command, "format"))
-        puts(FASTFETCH_DATATEXT_HELP_FORMAT);
     else if(ffStrEqualsIgnCase(command, "format-json"))
         printCommandFormatHelpJson();
     else if(ffCharIsEnglishAlphabet(command[0]) && ffStrEndsWithIgnCase(command, "-format")) // <module>-format
@@ -374,13 +374,13 @@ static void listModules(bool pretty)
     }
 }
 
-static bool parseJsoncFile(const char* path)
+static bool parseJsoncFile(const char* path, bool strictJson)
 {
     assert(!instance.state.configDoc);
 
     {
         yyjson_read_err error;
-        instance.state.configDoc = yyjson_read_file(path, YYJSON_READ_ALLOW_COMMENTS | YYJSON_READ_ALLOW_TRAILING_COMMAS, NULL, &error);
+        instance.state.configDoc = yyjson_read_file(path, strictJson ? 0 : YYJSON_READ_ALLOW_COMMENTS | YYJSON_READ_ALLOW_TRAILING_COMMAS, NULL, &error);
         if (!instance.state.configDoc)
         {
             if (error.code != YYJSON_READ_ERROR_FILE_OPEN)
@@ -452,57 +452,54 @@ static void optionParseConfigFile(FFdata* data, const char* key, const char* val
         fprintf(stderr, "Error: usage: %s <config>\n", key);
         exit(413);
     }
-    uint32_t fileNameLen = (uint32_t) strlen(value);
-    if(fileNameLen == 0)
-    {
-        fprintf(stderr, "Error: usage: %s <config>\n", key);
-        exit(413);
-    }
 
-    if (ffStrEqualsIgnCase(value, "none"))
+    if (value[0] == '\0' || ffStrEqualsIgnCase(value, "none"))
         return;
 
-    if (ffStrEndsWithIgnCase(value, ".conf"))
-    {
-        fprintf(stderr, "Error: flag based config files are no longer not supported: %s\n", value);
-        exit(414);
-    }
-
     //Try to load as an absolute path
 
-    if (parseJsoncFile(value)) return;
+    FF_STRBUF_AUTO_DESTROY absolutePath = ffStrbufCreateS(value);
+    bool strictJson = ffStrbufEndsWithIgnCaseS(&absolutePath, ".json");
+    bool needExtension = !strictJson && !ffStrbufEndsWithIgnCaseS(&absolutePath, ".jsonc");
+    if (needExtension)
+        ffStrbufAppendS(&absolutePath, ".jsonc");
 
-    FF_STRBUF_AUTO_DESTROY absolutePath = ffStrbufCreateA(128);
-
-    //Try to load as a relative path with the directory of fastfetch binary
-    if (instance.state.platform.exePath.length)
-    {
-        ffStrbufSet(&absolutePath, &instance.state.platform.exePath);
-        ffStrbufSubstrBeforeLastC(&absolutePath, '/');
-        ffStrbufAppendS(&absolutePath, "/");
-        ffStrbufAppendS(&absolutePath, value);
-
-        if (parseJsoncFile(absolutePath.chars)) return;
-        ffStrbufClear(&absolutePath);
-    }
+    if (parseJsoncFile(absolutePath.chars, strictJson)) return;
 
     //Try to load as a relative path
 
     FF_LIST_FOR_EACH(FFstrbuf, path, instance.state.platform.dataDirs)
     {
-        //We need to copy it, because if a config file loads a config file, the value of path must be unchanged
         ffStrbufSet(&absolutePath, path);
         ffStrbufAppendS(&absolutePath, "fastfetch/presets/");
         ffStrbufAppendS(&absolutePath, value);
-
-        bool success = parseJsoncFile(absolutePath.chars);
-        if (!success)
-        {
+        if (needExtension)
             ffStrbufAppendS(&absolutePath, ".jsonc");
-            success = parseJsoncFile(absolutePath.chars);
-        }
 
-        if (success) return;
+        if (parseJsoncFile(absolutePath.chars, strictJson)) return;
+    }
+
+    //Try to load as a relative path with the directory of fastfetch binary
+
+    if (instance.state.platform.exePath.length)
+    {
+        uint32_t lastSlash = ffStrbufLastIndexC(&instance.state.platform.exePath, '/') + 1;
+        assert(lastSlash < instance.state.platform.exePath.length);
+
+        // Try {exePath}/
+        ffStrbufSetNS(&absolutePath, lastSlash, instance.state.platform.exePath.chars);
+        ffStrbufAppendS(&absolutePath, value);
+        if (needExtension)
+            ffStrbufAppendS(&absolutePath, ".jsonc");
+        if (parseJsoncFile(absolutePath.chars, strictJson)) return;
+
+        // Try {exePath}/presets/
+        ffStrbufSubstrBefore(&absolutePath, lastSlash);
+        ffStrbufAppendS(&absolutePath, "presets/");
+        ffStrbufAppendS(&absolutePath, value);
+        if (needExtension)
+            ffStrbufAppendS(&absolutePath, ".jsonc");
+        if (parseJsoncFile(absolutePath.chars, strictJson)) return;
     }
 
     //File not found
@@ -665,7 +662,7 @@ static void parseConfigFiles(void)
             uint32_t dirLength = dir->length;
 
             ffStrbufAppendS(dir, "fastfetch/config.jsonc");
-            bool success = parseJsoncFile(dir->chars);
+            bool success = parseJsoncFile(dir->chars, false);
             ffStrbufSubstrBefore(dir, dirLength);
             if (success) return;
         }
